@@ -87,5 +87,18 @@ def enter(num=1):
 			
 			
 	
-if __name__=='__main__':
-	pass
\ No newline at end of file
+def readcode(code):
+	_code=''
+	code_=''
+	adding_code=True
+	addingcode_=False
+	for word in code:
+		if word==' ' and addingcode_==False:
+			adding_code=False
+			addingcode_=True
+			continue
+		if adding_code==True:
+			_code+=word
+		if addingcode_==True:
+			code_+=word
+	return (_code,code_)
\ No newline at end of file
